<?php

// No direct access to this file
defined('_JEXEC') or die('Restricted access');


use Joomla\CMS\Application\ApplicationHelper;

// import Joomla modelform library
jimport('joomla.application.component.modeladmin');

class MELOModelWlink extends JModelAdmin
{
	protected $text_prefix = 'COM_MELO_WLINK';
	
	protected function canDelete($record)
	{
		if (!empty($record->id))
		{
			if ($record->state != -2)
			{
				return;
			}
			$user = JFactory::getUser();
	
			if ($record->catid)
			{
				return $user->authorise('core.delete', 'com_melo.category.'.(int) $record->catid);
			}
			else
			{
				return parent::canDelete($record);
			}
		}
	}
	
	protected function canEditState($record)
	{
		$user = JFactory::getUser();
	
		if (!empty($record->catid))
		{
			return $user->authorise('core.edit.state', 'com_melo.category.'.(int) $record->catid);
		}
		else
		{
			return parent::canEditState($record);
		}
	}
	
	public function getTable($type = 'WLink', $prefix = 'MELOTable', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}
	
	public function getForm($data = array(), $loadData = true)
	{
		$app = JFactory::getApplication();
	
		// Get the form.
		$form = $this->loadForm('com_melo.wlink', 'wlink', array('control' => 'jform', 'load_data' => $loadData));
		if (empty($form))
		{
			return false;
		}
	
		// Determine correct permissions to check.
		if ($this->getState('wlink.id'))
		{
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.edit');
		}
		else
		{
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.create');
		}
	
		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data))
		{
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');
			$form->setFieldAttribute('publish_up', 'disabled', 'true');
			$form->setFieldAttribute('publish_down', 'disabled', 'true');
	
			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
			$form->setFieldAttribute('publish_up', 'filter', 'unset');
			$form->setFieldAttribute('publish_down', 'filter', 'unset');
		}
	
		return $form;
	}
	
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState('com_melo.edit.wlink.data', array());
	
		if (empty($data))
		{
			$data = $this->getItem();
	
			// Prime some default values.
			if ($this->getState('wlink.id') == 0)
			{
				$app = JFactory::getApplication();
				$data->set('catid', $app->input->get('catid', $app->getUserState('com_melo.wlinks.filter.category_id'), 'int'));
			}
		}
	
		$this->preprocessData('com_melo.wlink', $data);
	
		return $data;
	}
	
	protected function prepareTable($table)
	{
		$date = JFactory::getDate();
		$user = JFactory::getUser();
	
		$table->name		= htmlspecialchars_decode($table->name, ENT_QUOTES);
		$table->alias		= ApplicationHelper::stringURLSafe($table->alias);
	
		if (empty($table->alias))
		{
			$table->alias = ApplicationHelper::stringURLSafe($table->name);
		}
	
		if (empty($table->id))
		{
			// Set the values
	
			// Set ordering to the last item if not set
			if (empty($table->ordering))
			{
				$db = JFactory::getDbo();
				$db->setQuery('SELECT MAX(ordering) FROM #__melo_links');
				$max = $db->loadResult();
	
				$table->ordering = $max + 1;
			}
			else
			{
				// Set the values
				$table->modified	= $date->toSql();
				$table->modified_by	= $user->get('id');
			}
		}
	}

	protected function getReorderConditions($table)
	{
		$condition = array();
		$condition[] = 'catid = '.(int) $table->catid;
		return $condition;
	}
	
	public function save($data)
	{
		$app = JFactory::getApplication();
	
		// Alter the title for save as copy
		if ($app->input->get('task') == 'save2copy')
		{
			list($name, $alias) = $this->generateNewTitle($data['catid'], $data['alias'], $data['name']);
			$data['name']	= $name;
			$data['alias']	= $alias;
			$data['state']	= 0;
		}
		$return = parent::save($data);
	
		return $return;
	}
	
	protected function generateNewTitle($category_id, $alias, $name)
	{
		// Alter the title & alias
		$table = $this->getTable();
	
		while ($table->load(array('alias' => $alias, 'catid' => $category_id)))
		{
			if ($name == $table->name)
			{
				$name = JString::increment($name);
			}
			$alias = JString::increment($alias, 'dash');
		}
	
		return array($name, $alias);
	}
}
