<?php
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Component\Router\RouterView;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Log\Log;
use Joomla\CMS\Router\Router;
use Joomla\CMS\Uri\Uri;

defined('_JEXEC') or die;

class MeloRouter extends RouterView
{
	public function __construct($app = null, $menu = null)
	{
		$params = JComponentHelper::getParams('com_melo');

		parent::__construct($app, $menu);

		$this->attachRule(new JComponentRouterRulesMenu($this));
		$this->attachRule(new JComponentRouterRulesStandard($this));
		$this->attachRule(new JComponentRouterRulesNomenu($this));

		// needed for Joomla 4
		$router = $app::getRouter();
		$router->attachParseRule([$this, 'parseProcessAfter'], Router::PROCESS_AFTER);
	}

	/**
	 * Build method for URLs
	 *
	 * @param   array  &$query  Array of query elements
	 *
	 * @return  array  Array of URL segments
	 *
	 * @since   3.5
	 */
	public function build(&$query)
	{
		$segments = array();

		if (isset($query['id'])) $id = $query['id'];
		if (isset($id)) {
			$segments[] = $id;
			unset($query['id']);
		}
		unset($query['view']);

		// Process the parsed variables based on custom defined rules
		foreach ($this->rules as $rule)
		{
			$rule->build($query, $segments);
		}

		return $segments;
	}

	/**
	 * Parse method for URLs
	 *
	 * @param   array  &$segments  Array of URL string-segments
	 *
	 * @return  array  Associative array of query values
	 *
	 * @since   3.5
	 */
	public function parse(&$segments)
	{
		$vars = array();

		// Count route segments
		$count = count($segments);
		// Standard routing
		if ($count) {
			$linkid		= $segments[0];
			if (isset($linkid)) {
				$vars['id'] = (int)$linkid;
				$vars['view'] = "golink";
				$vars['option'] = "com_melo";
			}
		}

		// Process the parsed variables based on custom defined rules
		foreach ($this->rules as $rule)
		{
			$rule->parse($segments, $vars);
		}

		return $vars;
	}

	/**
	 * @param Router $router
	 * @param Uri    $uri
	 *
	 * @return void
	 */
	public function parseProcessAfter(Router $router, Uri $uri)
	{
		// Kinda crazy but needed in Joomla 4
		$uri->setPath(null);
	}

}


/**
 * Build the route for the com_weblinks component
 *
 * @param	array	An array of URL arguments
 *
 * @return	array	The URL arguments to use to assemble the subsequent URL.
 */
function MELOBuildRoute(&$query)
{
	$app = JFactory::getApplication();
	$router = new MeloRouter($app, $app->getMenu());

	return $router->build($query);

}
/**
 * Parse the segments of a URL.
 *
 * @param	array	The segments of the URL to parse.
 *
 * @return	array	The URL attributes to be used by the application.
 */
function MELOParseRoute($segments)
{
	$app = JFactory::getApplication();
	$router = new MeloRouter($app, $app->getMenu());

	return $router->parse($segments);
}
